A script to download lecture videos for a udemy course.

### Install

Udemy can be installed using pip

    sudo pip install udemy-dl

If you don't have pip installed, look [here](http://pip.readthedocs.org/en/latest/installing.html). Or if you trust me:

    sudo curl https://bootstrap.pypa.io/get-pip.py | python


### Use

    udemy-dl -u email udemy_course_link

Then you will be prompted for your udemy password.

For information about other parameters, use the `--help` parameter

    udemy-dl --help
